==> sapdb-source-7.3.00.48.tgz: V73_00_48/SAPDB_ORG/sys/src/eo/veo49.c <==
/****************************************************************************

  module      : veo49.c

  -------------------------------------------------------------------------

  responsible : JoergM

  special area: Security functions
  description : Security specific functions

  last changed: 2000-06-05  11:15
  see also    : example.html ...

  -------------------------------------------------------------------------

  copyright:    Copyright by SAP AG, 1999



    ========== licence begin LGPL
    Copyright (C) 2000 SAP AG

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
    ========== licence end

*****************************************************************************/



/*===========================================================================*
 *  INCLUDES                                                                 *
 *===========================================================================*/

#include "gsp00.h"
#include "geo49.h"

#if defined(WIN32)
#include "gos00.h" /* nocheck */
#include <aclapi.h>
#else
#include <pwd.h>
#include <sys/stat.h>
#include <fcntl.h>
#endif

/*===========================================================================*
 *  DEFINES                                                                  *
 *===========================================================================*/


/*===========================================================================*
 *  MACROS                                                                   *
 *===========================================================================*/



/*===========================================================================*
 *  LOCAL CLASSES, STRUCTURES, TYPES, UNIONS ...                             *
 *===========================================================================*/



/*===========================================================================*
 *  STATIC/INLINE FUNCTIONS (PROTOTYPES)                                     *
 *===========================================================================*/



/*===========================================================================*
 *  PUBLIC FUNCTIONS (CODE)                                                  *
 *===========================================================================*/

externC bool eo49GetFileOwner(
const teo49_FileHandle FileHandle, 
tsp00_UserNamec OwnerName)
{
#if defined(WIN32)
    TCHAR Account[sizeof(tsp00_UserNamec)];
    TCHAR Domain[sizeof(tsp00_UserNamec)];
    PSID OwnerSID;
    PSECURITY_DESCRIPTOR SecurityDescriptor;
    SID_NAME_USE aUser = SidTypeUser;

    if ( sql02_get_platform_id() != VER_PLATFORM_WIN32_NT )
    {
        DWORD NameSize = sizeof(tsp00_UserName);
        return ( GetUserName( (char *)OwnerName, &NameSize) != 0 );
    }
    else
    {
        bool ok;
        DWORD AccountSize = sizeof(tsp00_UserName);
        DWORD DomainSize = sizeof(tsp00_UserName);

        if ( GetSecurityInfo( FileHandle,
                              SE_FILE_OBJECT,
                              OWNER_SECURITY_INFORMATION,
                             &OwnerSID,
                              NULL, // Group SID not needed
                              NULL, // DACL not needed
                              NULL, // SACL not needed
                             &SecurityDescriptor ) != ERROR_SUCCESS )
        {
            return false;
        }

        ok = ( LookupAccountSid( NULL,
                               OwnerSID,
                               Account,
                              &AccountSize,
                               Domain,
                              &DomainSize,
                              &aUser ) != false );

        LocalFree(SecurityDescriptor);

        if ( ok )
        {
            if ( strcmp(Domain, "BUILTIN") != 0 )
            {
                ok = ( (strlen(Account) + strlen(Domain)) < sizeof(tsp00_UserName) );
                if ( ok )
                {
                    strcpy(OwnerName, Domain);
                    strcat(OwnerName, "\\");
                    strcat(OwnerName, Account);
                }
            }
            else
            {
                strcpy(OwnerName, Account);
            }
        }
        return ok;
    }
#else
    struct stat statBuffer;

    if ( fstat(FileHandle, &statBuffer) == 0 )
    {
        struct passwd *pwEntry;
        
        pwEntry = getpwuid(statBuffer.st_uid);
        if ( !pwEntry )
        {
            return false;
        }
        strcpy(OwnerName, pwEntry->pw_name);
        return true;
    }
    return false;    
#endif
}

/*===========================================================================*
 *  LOCAL/PRIVATE/PROTECTED FUNCTIONS (CODE)                                 *
 *===========================================================================*/

/*===========================================================================*
 *  END OF CODE                                                              *
 *===========================================================================*/

==> sapdb-source-7.4.03.32.tgz: V74_03_32/SAPDB_ORG/sys/src/eo/veo49.c <==
/****************************************************************************

  module      : veo49.c

  -------------------------------------------------------------------------

  responsible : JoergM

  special area: Security functions
  description : Security specific functions

  last changed: 2000-12-05  11:46
  see also    : example.html ...

  -------------------------------------------------------------------------

  copyright:    Copyright by SAP AG, 1999



    ========== licence begin LGPL
    Copyright (C) 2000 SAP AG

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
    ========== licence end

*****************************************************************************/



/*===========================================================================*
 *  INCLUDES                                                                 *
 *===========================================================================*/

#include "gsp00.h"
#include "geo49.h"

#if defined(WIN32)
#include "gos00.h" /* nocheck */
#include <aclapi.h>
#else
#include <pwd.h>
#include <sys/stat.h>
#include <fcntl.h>
#endif

/*===========================================================================*
 *  DEFINES                                                                  *
 *===========================================================================*/


/*===========================================================================*
 *  MACROS                                                                   *
 *===========================================================================*/



/*===========================================================================*
 *  LOCAL CLASSES, STRUCTURES, TYPES, UNIONS ...                             *
 *===========================================================================*/



/*===========================================================================*
 *  STATIC/INLINE FUNCTIONS (PROTOTYPES)                                     *
 *===========================================================================*/



/*===========================================================================*
 *  PUBLIC FUNCTIONS (CODE)                                                  *
 *===========================================================================*/

externC bool eo49GetFileOwner(
const teo49_FileHandle FileHandle, 
tsp00_KnlIdentifierc OwnerName)
{
#if defined(WIN32)
    TCHAR Account[sizeof(tsp00_KnlIdentifierc)];
    TCHAR Domain[sizeof(tsp00_KnlIdentifierc)];
    PSID OwnerSID;
    PSECURITY_DESCRIPTOR SecurityDescriptor;
    SID_NAME_USE aUser = SidTypeUser;

    if ( sql02_get_platform_id() != VER_PLATFORM_WIN32_NT )
    {
        DWORD NameSize = sizeof(tsp00_KnlIdentifier);
        return ( GetUserName( (char *)OwnerName, &NameSize) != 0 );
    }
    else
    {
        bool ok;
        DWORD AccountSize = sizeof(tsp00_KnlIdentifier);
        DWORD DomainSize = sizeof(tsp00_KnlIdentifier);

        if ( GetSecurityInfo( FileHandle,
                              SE_FILE_OBJECT,
                              OWNER_SECURITY_INFORMATION,
                             &OwnerSID,
                              NULL, // Group SID not needed
                              NULL, // DACL not needed
                              NULL, // SACL not needed
                             &SecurityDescriptor ) != ERROR_SUCCESS )
        {
            return false;
        }

        ok = ( LookupAccountSid( NULL,
                               OwnerSID,
                               Account,
                              &AccountSize,
                               Domain,
                              &DomainSize,
                              &aUser ) != false );

        LocalFree(SecurityDescriptor);

        if ( ok )
        {
            if ( strcmp(Domain, "BUILTIN") != 0 )
            {
                ok = (bool)( (strlen(Account) + strlen(Domain)) < sizeof(tsp00_KnlIdentifier) );
                if ( ok )
                {
                    strcpy(OwnerName, Domain);
                    strcat(OwnerName, "\\");
                    strcat(OwnerName, Account);
                }
            }
            else
            {
                strcpy(OwnerName, Account);
            }
        }
        return ok;
    }
#else
    struct stat statBuffer;

    if ( fstat(FileHandle, &statBuffer) == 0 )
    {
        struct passwd *pwEntry;
        
        pwEntry = getpwuid(statBuffer.st_uid);
        if ( !pwEntry )
        {
            return false;
        }
        strcpy(OwnerName, pwEntry->pw_name);
        return true;
    }
    return false;    
#endif
}

/*===========================================================================*
 *  LOCAL/PRIVATE/PROTECTED FUNCTIONS (CODE)                                 *
 *===========================================================================*/

/*===========================================================================*
 *  END OF CODE                                                              *
 *===========================================================================*/
